Name:		dosbox-staging
Version:	0.80.1
Release:	%mkrel 1
Summary:	A modernized DOSBox to run old DOS games
License:	GPLv2+
Group:		Emulators
URL:		https://dosbox-staging.github.io/

Source0:	https://github.com/dosbox-staging/dosbox-staging/archive/v%{version}/%{name}-%{version}.tar.gz
# launcher to workaround the lack of keyboard layout detection
# see also https://github.com/dosbox-staging/dosbox-staging/issues/394
Source1:	dosbox
# Example of config file to ease with change of variable name
# Need to be generated with the current version of dosbox staging 
Source2:	%{name}.conf.example

# We prefer dosbox-staging as program name (see launcher above)
Patch0:		dosbox-staging-fix-program-name-with-meson.patch

BuildRequires:	meson
BuildRequires:	pkgconfig(iir)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(SDL2_image)
BuildRequires:	pkgconfig(SDL2_net)
BuildRequires:	pkgconfig(opusfile)
BuildRequires:	pkgconfig(fluidsynth) > 2
BuildRequires:	pkgconfig(gtest)
BuildRequires:	pkgconfig(mt32emu)
BuildRequires:	pkgconfig(slirp)
BuildRequires:	pkgconfig(speexdsp)
BuildRequires:	pkgconfig(xi)


Provides:	dosbox = %{version}
Conflicts:	dosbox

%description
dosbox-staging is DOS/x86 emulator focusing on ease of use.

Based on DOSBox, it is a fork which use modern library (e.g.: sdl2) and 
practice in an attempt to revitalize the development process.

It prioritize DOS gaming, while welcoming general improvements (such as for 
productivity software) that don't impact game emulation quality 
or code-maintainability.

Some unique features: SDL2, pixel-perfect mode, resizable window, experimental 
wayland support, better OPL3 emulation, MP3, FLAC, VORBIS, OPUS support and 
many more (see https://dosbox-staging.github.io for a complete list).


DOSBox is a DOS-emulator that uses the SDL-library which makes DOSBox 
very easy to port to different platforms. DOSBox has already been ported 
to many different platforms, such as Windows, BeOS, Linux, MacOS X...

DOSBox also emulates CPU:286/386 realmode/protected mode,
Directory FileSystem/XMS/EMS, Tandy/Hercules/CGA/EGA/VGA/VESA
graphics, a SoundBlaster/Gravis Ultra Sound card for excellent
sound compatibility with older games.


%prep
%setup -q
%autopatch -p0

mv docs/dosbox.1 docs/dosbox-staging.1

%build
%meson

%meson_build

%install
%meson_install

#Launcher
install -m 0755 %{SOURCE1} %{buildroot}%{_bindir}

#Configuration file example
install -Dm 0644 %{SOURCE2} %{buildroot}%{_docdir}/%{name}/%{name}.conf.example

%files
%license COPYING
%doc AUTHORS CODE_OF_CONDUCT.md CONTRIBUTING.md README README.md THANKS docs/README.video
%{_bindir}/%{name}
%{_bindir}/dosbox
%{_datadir}/applications/*.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.*
%{_metainfodir}/%{name}.metainfo.xml
%{_docdir}/%{name}/%{name}.conf.example
%{_datadir}/%{name}/
%{_mandir}/man1/%{name}*


%changelog
* Mon Jan 16 2023 julien <julien> 0.80.1-1.mga9
+ Revision: 1933846
- new version 0.80.1

* Fri Dec 23 2022 daviddavid <daviddavid> 0.80.0-1.mga9
+ Revision: 1926106
- new version: 0.80.0

* Sun Mar 20 2022 julien <julien> 0.78.1-1.mga9
+ Revision: 1808689
- new version 0.78.1
- adjust keyboard layout script to avoid X11 dependency
- rediff meson build patch

* Sun Aug 29 2021 julien <julien> 0.77.1-1.mga9
+ Revision: 1743548
- new version 0.77.1

* Thu Aug 05 2021 luigiwalser <luigiwalser> 0.77.0-2.mga9
+ Revision: 1739413
- rebuild for fluidsynth

* Fri Jul 09 2021 julien <julien> 0.77.0-1.mga9
+ Revision: 1735468
- new version 0.77.0
- adjust to meson build system
- add dependance to mt32emu

* Thu Dec 03 2020 julien <julien> 0.76.0-1.mga8
+ Revision: 1652325
- add some information in specfile
- new version 0.76.0
- add fluidsynth BR to enable good midi emulation
- add an example of config file generated with this version
- install Appstream metainfo

* Tue Oct 27 2020 julien <julien> 0.75.2-1.mga8
+ Revision: 1639900
- new version 0.75.2
- drop patch0, merged by upstream
- adjust build flags according to upstream

* Wed Aug 19 2020 julien <julien> 0.75.1-1.mga8
+ Revision: 1616338
- new version 0.75.1
- adjust tarball filename

* Sat May 23 2020 julien <julien> 0.75.0-1.mga8
+ Revision: 1587151
- fix %%configure
- imported package dosbox-staging

